@@ -25,10 +25,13 @@ pub trait Refresh {
 
 /// A type that can be converted into a verified representation.
 pub trait IntoVerified {
-    /// Conver this object into the same object with verification.
-    fn into_verified(self, session: &Session) -> Result<Self>
+    /// Convert this object into the same object with verification.
+    fn into_verified(self, _session: &Session) -> Result<Self>
     where
-        Self: Sized;
+        Self: Sized,
+    {
+        Ok(self)
+    }
 }
 
 macro_rules! opaque_resource_type {
@@ -114,15 +117,12 @@ macro_rules! opaque_resource_type {
 
         #[cfg(not(feature = $service))]
         #[allow(dead_code)]
-        impl $crate::common::IntoVerified for $name {
-            fn into_verified(self, _session: &$crate::session::Session)
-                    -> $crate::Result<$name> {
-                Ok(self)
-            }
-        }
+        impl $crate::common::IntoVerified for $name {}
     )
 }
 
+opaque_resource_type!(#[doc = "An ID of a `Container`"] ContainerRef ? "object-storage");
+
 opaque_resource_type!(#[doc = "An ID of a `Flavor`"] FlavorRef ? "compute");
 
 opaque_resource_type!(#[doc = "An ID of an `Image`"] ImageRef ? "image");
@@ -131,12 +131,16 @@ opaque_resource_type!(#[doc = "An ID of a `KeyPair`"] KeyPairRef ? "compute");
 
 opaque_resource_type!(#[doc = "An ID of a `Network`"] NetworkRef ? "network");
 
+opaque_resource_type!(#[doc = "An ID of an `Object`"] ObjectRef ? "object-storage");
+
 opaque_resource_type!(#[doc = "An ID of a `Project`"] ProjectRef ? "identity");
 
 opaque_resource_type!(#[doc = "An ID of a `Port`"] PortRef ? "network");
 
 opaque_resource_type!(#[doc = "An ID of a `Router`"] RouterRef ? "network");
 
+opaque_resource_type!(#[doc = "An ID of a `SecurityGroup`"] SecurityGroupRef ? "network");
+
 opaque_resource_type!(#[doc = "An ID of a `Snapshot`"] SnapshotRef ? "volume");
 
 opaque_resource_type!(#[doc = "An ID of a `Subnet`"] SubnetRef ? "network");
