@@ -18,15 +18,13 @@ use std::collections::HashMap;
 use std::rc::Rc;
 
 use fallible_iterator::{FallibleIterator, IntoFallibleIterator};
+use osproto::common::IdAndName;
 
-use super::super::common::{
-    self, FlavorRef, IntoVerified, Refresh, ResourceIterator, ResourceQuery,
-};
+use super::super::common::{FlavorRef, IntoVerified, Refresh, ResourceIterator, ResourceQuery};
 use super::super::session::Session;
 use super::super::utils::Query;
 use super::super::{Error, Result};
-use super::base::V2API;
-use super::protocol;
+use super::{api, protocol};
 
 /// Structure representing a flavor.
 #[derive(Clone, Debug)]
@@ -40,7 +38,7 @@ pub struct Flavor {
 #[derive(Clone, Debug)]
 pub struct FlavorSummary {
     session: Rc<Session>,
-    inner: common::protocol::IdAndName,
+    inner: IdAndName,
 }
 
 /// A query to flavor list.
@@ -62,7 +60,7 @@ impl Flavor {
     pub(crate) fn new(session: Rc<Session>, mut inner: protocol::Flavor) -> Result<Flavor> {
         let extra_specs = match inner.extra_specs.take() {
             Some(es) => es,
-            None => session.get_extra_specs_by_flavor_id(&inner.id)?,
+            None => api::get_extra_specs_by_flavor_id(&session, &inner.id)?,
         };
 
         Ok(Flavor {
@@ -74,7 +72,7 @@ impl Flavor {
 
     /// Load a Flavor object.
     pub(crate) fn load<Id: AsRef<str>>(session: Rc<Session>, id: Id) -> Result<Flavor> {
-        let inner = session.get_flavor(id)?;
+        let inner = api::get_flavor(&session, id)?;
         Flavor::new(session, inner)
     }
 
@@ -131,7 +129,7 @@ impl Flavor {
 impl Refresh for Flavor {
     /// Refresh the flavor.
     fn refresh(&mut self) -> Result<()> {
-        self.inner = self.session.get_flavor_by_id(&self.inner.id)?;
+        self.inner = api::get_flavor_by_id(&self.session, &self.inner.id)?;
         Ok(())
     }
 }
@@ -199,20 +197,6 @@ impl FlavorQuery {
         ResourceIterator::new(self)
     }
 
-    /// Convert this query into an iterator executing the request.
-    ///
-    /// This iterator yields full `Flavor` objects. If you only need IDs
-    /// and/or names, use `into_iter` to save bandwidth.
-    ///
-    /// Returns a `FallibleIterator`, which is an iterator with each `next`
-    /// call returning a `Result`.
-    ///
-    /// Note that no requests are done until you start iterating.
-    #[deprecated(since = "0.2.0", note = "Use .detailed().into_iter()")]
-    pub fn into_iter_detailed(self) -> ResourceIterator<DetailedFlavorQuery> {
-        self.detailed().into_iter()
-    }
-
     /// Execute this request and return all results.
     ///
     /// A convenience shortcut for `self.into_iter().collect()`.
@@ -251,9 +235,7 @@ impl ResourceQuery for FlavorQuery {
 
     fn fetch_chunk(&self, limit: Option<usize>, marker: Option<String>) -> Result<Vec<Self::Item>> {
         let query = self.query.with_marker_and_limit(limit, marker);
-        Ok(self
-            .session
-            .list_flavors(&query)?
+        Ok(api::list_flavors(&self.session, &query)?
             .into_iter()
             .map(|item| FlavorSummary {
                 session: self.session.clone(),
@@ -293,7 +275,7 @@ impl ResourceQuery for DetailedFlavorQuery {
 
     fn fetch_chunk(&self, limit: Option<usize>, marker: Option<String>) -> Result<Vec<Self::Item>> {
         let query = self.inner.query.with_marker_and_limit(limit, marker);
-        let flavors = self.inner.session.list_flavors_detail(&query)?;
+        let flavors = api::list_flavors_detail(&self.inner.session, &query)?;
         let mut result = Vec::with_capacity(flavors.len());
         for item in flavors {
             result.push(Flavor::new(self.inner.session.clone(), item)?);
@@ -307,9 +289,9 @@ impl IntoFallibleIterator for FlavorQuery {
 
     type Error = Error;
 
-    type IntoIter = ResourceIterator<FlavorQuery>;
+    type IntoFallibleIter = ResourceIterator<FlavorQuery>;
 
-    fn into_fallible_iterator(self) -> Self::IntoIter {
+    fn into_fallible_iter(self) -> Self::IntoFallibleIter {
         self.into_iter()
     }
 }
@@ -319,9 +301,9 @@ impl IntoFallibleIterator for DetailedFlavorQuery {
 
     type Error = Error;
 
-    type IntoIter = ResourceIterator<DetailedFlavorQuery>;
+    type IntoFallibleIter = ResourceIterator<DetailedFlavorQuery>;
 
-    fn into_fallible_iterator(self) -> Self::IntoIter {
+    fn into_fallible_iter(self) -> Self::IntoFallibleIter {
         self.into_iter()
     }
 }
@@ -345,7 +327,7 @@ impl IntoVerified for FlavorRef {
         Ok(if self.verified {
             self
         } else {
-            FlavorRef::new_verified(session.get_flavor(&self.value)?.id)
+            FlavorRef::new_verified(api::get_flavor(session, &self.value)?.id)
         })
     }
 }
