@@ -16,9 +16,9 @@ extern crate env_logger;
 extern crate fallible_iterator;
 extern crate openstack;
 
-use std::sync::{Once, ONCE_INIT};
+use std::sync::Once;
 
-static INIT: Once = ONCE_INIT;
+static INIT: Once = Once::new();
 
 fn set_up() -> openstack::Cloud {
     INIT.call_once(|| {
